@@ -8,7 +8,7 @@ typedef long int (*sfun)(long int __sysno, ...);
 #define PUREFLAG_STDERR (1<<STDERR_FILENO)
 #define PUREFLAG_STDALL (PUREFLAG_STDIN|PUREFLAG_STDOUT|PUREFLAG_STDERR)
 
-sfun _pure_start(sfun pure_syscall,sfun pure_socketcall,int flags);
+sfun _pure_start(sfun pure_syscall, int flags);
 
 long _pure_debug_printf(const char *format, ...);
 
